pub struct TaskInfo {
pub task_type: i32,
pub name: String,
pub language: i32,
pub task_id: Vec<u8>,
pub detail: Option<TaskDetail>,
pub execute_mode: i32,
pub env_id: String,
}Expand description
TaskInfo is the task information
Fields
task_type: i32name: Stringlanguage: i32task_id: Vec<u8>detail: Option<TaskDetail>execute_mode: i32env_id: StringUnique id of the environment
Implementations
Sourceimpl TaskInfo
impl TaskInfo
Sourcepub fn task_type(&self) -> TaskType
pub fn task_type(&self) -> TaskType
Returns the enum value of task_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_task_type(&mut self, value: TaskType)
pub fn set_task_type(&mut self, value: TaskType)
Sets task_type to the provided enum value.
Sourcepub fn language(&self) -> Language
pub fn language(&self) -> Language
Returns the enum value of language, or the default if the field is set to an invalid enum value.
Sourcepub fn set_language(&mut self, value: Language)
pub fn set_language(&mut self, value: Language)
Sets language to the provided enum value.
Sourcepub fn execute_mode(&self) -> TaskExecuteMode
pub fn execute_mode(&self) -> TaskExecuteMode
Returns the enum value of execute_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_execute_mode(&mut self, value: TaskExecuteMode)
pub fn set_execute_mode(&mut self, value: TaskExecuteMode)
Sets execute_mode to the provided enum value.